<?php
/**
 * Customizer active callbacks
 *
 * @package Theme Palace
 * @subpackage Mega Blog Pro
 * @since Mega Blog Pro 1.0.0
 */

if ( ! function_exists( 'mega_blog_pro_is_loader_enable' ) ) :
	/**
	 * Check if loader is enabled.
	 *
	 * @since Mega Blog Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function mega_blog_pro_is_loader_enable( $control ) {
		return $control->manager->get_setting( 'mega_blog_pro_theme_options[loader_enable]' )->value();
	}
endif;

if ( ! function_exists( 'mega_blog_pro_is_pagination_enable' ) ) :
	/**
	 * Check if pagination is enabled.
	 *
	 * @since Mega Blog Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function mega_blog_pro_is_pagination_enable( $control ) {
		return $control->manager->get_setting( 'mega_blog_pro_theme_options[pagination_enable]' )->value();
	}
endif;

/**
 * Front Page Active Callbacks
 */
/**
 * Check if topbar section is enabled.
 *
 * @since Mega Blog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_blog_pro_is_topbar_section_enable( $control ) {
	return ( $control->manager->get_setting( 'mega_blog_pro_theme_options[topbar_section_enable]' )->value() );
}

/**
 * Check if message section is enabled.
 *
 * @since Mega Blog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_blog_pro_is_message_section_enable( $control ) {
	return ( $control->manager->get_setting( 'mega_blog_pro_theme_options[message_section_enable]' )->value() );
}

/**
 * Check if message section content type is post.
 *
 * @since Mega Blog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_blog_pro_is_message_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_blog_pro_theme_options[message_content_type]' )->value();
	return mega_blog_pro_is_message_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if message section content type is page.
 *
 * @since Mega Blog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_blog_pro_is_message_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_blog_pro_theme_options[message_content_type]' )->value();
	return mega_blog_pro_is_message_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if message section content type is custom.
 *
 * @since Mega Blog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_blog_pro_is_message_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_blog_pro_theme_options[message_content_type]' )->value();
	return mega_blog_pro_is_message_section_enable( $control ) && ( 'custom' == $content_type );
}

/**
 * Check if featured section is enabled.
 *
 * @since Mega Blog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_blog_pro_is_featured_section_enable( $control ) {
	return ( $control->manager->get_setting( 'mega_blog_pro_theme_options[featured_section_enable]' )->value() );
}

/**
 * Check if featured section content type is page.
 *
 * @since Mega Blog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_blog_pro_is_featured_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_blog_pro_theme_options[featured_content_type]' )->value();
	return mega_blog_pro_is_featured_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if featured section content type is category.
 *
 * @since Mega Blog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_blog_pro_is_featured_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_blog_pro_theme_options[featured_content_type]' )->value();
	return mega_blog_pro_is_featured_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if featured section content type is recent.
 *
 * @since Mega Blog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_blog_pro_is_featured_section_content_recent_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_blog_pro_theme_options[featured_content_type]' )->value();
	return mega_blog_pro_is_featured_section_enable( $control ) && ( 'recent' == $content_type );
}

/**
 * Check if featured section content type is post.
 *
 * @since Mega Blog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_blog_pro_is_featured_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_blog_pro_theme_options[featured_content_type]' )->value();
	return mega_blog_pro_is_featured_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if recent section is enabled.
 *
 * @since Mega Blog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_blog_pro_is_recent_section_enable( $control ) {
	return ( $control->manager->get_setting( 'mega_blog_pro_theme_options[recent_section_enable]' )->value() );
}

/**
 * Check if recent section content type is category.
 *
 * @since Mega Blog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_blog_pro_is_recent_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_blog_pro_theme_options[recent_content_type]' )->value();
	return mega_blog_pro_is_recent_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if recent section content type is recent.
 *
 * @since Mega Blog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_blog_pro_is_recent_section_content_recent_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_blog_pro_theme_options[recent_content_type]' )->value();
	return mega_blog_pro_is_recent_section_enable( $control ) && ( 'recent' == $content_type );
}

/**
 * Check if gallery section is enabled.
 *
 * @since Mega Blog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_blog_pro_is_gallery_section_enable( $control ) {
	return ( $control->manager->get_setting( 'mega_blog_pro_theme_options[gallery_section_enable]' )->value() );
}

/**
 * Check if gallery section content type is category.
 *
 * @since Mega Blog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_blog_pro_is_gallery_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_blog_pro_theme_options[gallery_content_type]' )->value();
	return mega_blog_pro_is_gallery_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if gallery section content type is page.
 *
 * @since Mega Blog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_blog_pro_is_gallery_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_blog_pro_theme_options[gallery_content_type]' )->value();
	return mega_blog_pro_is_gallery_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if gallery section content type is post.
 *
 * @since Mega Blog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_blog_pro_is_gallery_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_blog_pro_theme_options[gallery_content_type]' )->value();
	return mega_blog_pro_is_gallery_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if popular section is enabled.
 *
 * @since Mega Blog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_blog_pro_is_popular_section_enable( $control ) {
	return ( $control->manager->get_setting( 'mega_blog_pro_theme_options[popular_section_enable]' )->value() );
}

/**
 * Check if popular section content type is post.
 *
 * @since Mega Blog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_blog_pro_is_popular_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_blog_pro_theme_options[popular_content_type]' )->value();
	return mega_blog_pro_is_popular_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if popular section content type is page.
 *
 * @since Mega Blog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_blog_pro_is_popular_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_blog_pro_theme_options[popular_content_type]' )->value();
	return mega_blog_pro_is_popular_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if popular section content type is category.
 *
 * @since Mega Blog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_blog_pro_is_popular_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_blog_pro_theme_options[popular_content_type]' )->value();
	return mega_blog_pro_is_popular_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if popular section content type is recent.
 *
 * @since Mega Blog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_blog_pro_is_popular_section_content_recent_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_blog_pro_theme_options[popular_content_type]' )->value();
	return mega_blog_pro_is_popular_section_enable( $control ) && ( 'recent' == $content_type );
}

/**
 * Check if contact section is enabled.
 *
 * @since Mega Blog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_blog_pro_is_contact_section_enable( $control ) {
	return ( $control->manager->get_setting( 'mega_blog_pro_theme_options[contact_section_enable]' )->value() );
}